public inbox for archer-commits@sourceware.org
help / color / mirror / Atom feed
From: sergiodj@sourceware.org
To: archer-commits@sourceware.org
Subject: [SCM]  archer-sergiodj-stap: Merge remote-tracking branch 'origin/master' into archer-sergiodj-stap
Date: Thu, 26 Jan 2012 21:12:00 -0000	[thread overview]
Message-ID: <20120126211212.15564.qmail@sourceware.org> (raw)

The branch, archer-sergiodj-stap has been updated
       via  8cfb9152ad5ffa41686efe5cdf7b02c9f2581162 (commit)
       via  826f42c0b80edf7ed6737c3cc4a231c814439717 (commit)
       via  8f01ee478b8a66f11754c2331dcd84adf7ba0928 (commit)
       via  f6f8515fb708026463c84749424096a9b45a38c7 (commit)
       via  edd5dfe523dbbfe252d8386e29092983d4ef3b9c (commit)
       via  facd11c8873e61e8f8834b6268b6b94608e54f44 (commit)
       via  4ddccbc58b822b0c35f0f46891a2d276d095ec2a (commit)
       via  8eb4602788d1c0b3da11b9383492a7cdb5657f9d (commit)
       via  0ada00d6182dce5160f8893a842f1ce6c8c96569 (commit)
       via  0d5b49f34332c76234f7bcbc64fa67fe6872ad54 (commit)
       via  4c6c0519ab462f6f69c2942e1857cb42a7d80066 (commit)
      from  1314192a3c7d31c64c17becfc9a43c4a6d0f2f4a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email.

- Log -----------------------------------------------------------------
commit 8cfb9152ad5ffa41686efe5cdf7b02c9f2581162
Merge: 826f42c 8f01ee4
Author: Sergio Durigan Junior <sergiodj@redhat.com>
Date:   Thu Jan 26 19:10:26 2012 -0200

    Merge remote-tracking branch 'origin/master' into archer-sergiodj-stap

commit 826f42c0b80edf7ed6737c3cc4a231c814439717
Author: Sergio Durigan Junior <sergiodj@redhat.com>
Date:   Thu Jan 26 19:09:42 2012 -0200

    Lots of small cleanups in the code.

commit 8f01ee478b8a66f11754c2331dcd84adf7ba0928
Author: Pedro Alves <pedro@codesourcery.com>
Date:   Thu Jan 26 16:44:29 2012 +0000

    2012-01-26  Pedro Alves  <palves@redhat.com>
    
    	* corelow.c (core_has_fake_pid): Delete.
    	(core_close): Delete references to `core_has_fake_pid'.
    	(add_to_thread_list): Adjust to mark the inferior's pid as fake.
    	(core_open): Delete references to `core_has_fake_pid'.
    	(core_pid_to_str): Adjust to check inferior->fake_pid_p instead of
    	the removed global.

commit f6f8515fb708026463c84749424096a9b45a38c7
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Thu Jan 26 14:28:30 2012 +0000

    	* make-relative-prefix.c (make_relative_prefix_1): Avoid warning
    	about using preprocessor directives inside of macro arguments.

commit edd5dfe523dbbfe252d8386e29092983d4ef3b9c
Author: Pedro Alves <pedro@codesourcery.com>
Date:   Thu Jan 26 10:50:59 2012 +0000

    2012-01-26  Pedro Alves  <palves@redhat.com>
    
    	* gdb.base/watchpoint.exp: Replace send_gdb/gdb_expect by gdb_test
    	and gdb_test_multiple.

commit facd11c8873e61e8f8834b6268b6b94608e54f44
Author: Pedro Alves <pedro@codesourcery.com>
Date:   Thu Jan 26 10:09:42 2012 +0000

    2012-01-26  Pedro Alves  <palves@redhat.com>
    
    	Make test messages unique, and more identifiable.
    	* gdb.multi/watchpoint-multi.exp: Change test messages.

commit 4ddccbc58b822b0c35f0f46891a2d276d095ec2a
Author: Joel Brobecker <brobecker@gnat.com>
Date:   Thu Jan 26 04:21:39 2012 +0000

    Remove language param from name_matcher in struct quick_symbol_functions
    
    The quick_symbol_functions struct contains a field which is pointer
    a function which takes another function, called name_matcher, as
    its parameter.  This name_matcher currently has 3 arguments, one
    of them being the language. This parameter is no longer used, and
    thus deleted.
    
    gdb/ChangeLog:
    
            * symfile.h (struct quick_symbol_functions) [expand_symtabs_matching]:
            Remove language parameter from name_matcher.  Adjust the comment.
            * symtab.c (search_symbols_name_matches, expand_partial_symbol_name):
            Remove language parameter.
            * ada-lang.c (ada_expand_partial_symbol_name): Likewise.
            * linespec.c (iterate_name_matcher): Likewise.
            * dwarf2read.c (dw2_expand_symtabs_matching): Adjust type of
            name_matcher.  Adjust call accordingly.
            * psymtab.c (expand_symtabs_matching_via_partial): Likewise.
            (maintenance_check_symtabs): Adjust type of parameter "fun".
            * psymtab.h (maintenance_check_symtabs): Likewise.

commit 8eb4602788d1c0b3da11b9383492a7cdb5657f9d
Author: Joel Brobecker <brobecker@gnat.com>
Date:   Thu Jan 26 04:20:31 2012 +0000

    Ada: allow unqualified function names in linespecs
    
    This is the meat, where we replace the old la_symbol_name_compare
    language method with the new ada_get_symbol_name_match_p.
    It fixes the problem when trying to insert a breakpoint on "+".
    
    gdb/ChangeLog:
    
            * language.h (symbol_name_match_p_ftype): New typedef.
            (struct language_defn): Replace field la_symbol_name_compare
            by la_get_symbol_name_match_p.
            * ada-lang.c (ada_get_symbol_name_match_p): New function.
            (ada_language_defn): Use it.
            * linespec.c (struct symbol_matcher_data): New type.
            (iterate_name_matcher): Rewrite.
            (iterate_over_all_matching_symtabs): Pass a pointer to
            a symbol_matcher_data struct to expand_symtabs_matching
            instead of just the lookup name.
            * c-lang.c, d-lang.c, jv-lang.c, m2-lang.c, objc-lang.c,
            opencl-lang.c, p-lang.c, language.c: Delete field
            la_symbol_name_compare, and replace by NULL for new field
            la_get_symbol_name_match_p.
            * symfile.h (struct quick_symbol_functions): Update comment.

commit 0ada00d6182dce5160f8893a842f1ce6c8c96569
Author: gdbadmin <gdbadmin@sourceware.org>
Date:   Thu Jan 26 00:00:02 2012 +0000

    *** empty log message ***

commit 0d5b49f34332c76234f7bcbc64fa67fe6872ad54
Author: Alan Modra <amodra@bigpond.net.au>
Date:   Wed Jan 25 23:00:06 2012 +0000

    daily update

commit 4c6c0519ab462f6f69c2942e1857cb42a7d80066
Author: Jan Kratochvil <jan.kratochvil@redhat.com>
Date:   Wed Jan 25 18:25:13 2012 +0000

    gdb/gdbserver/
    	* linux-low.c (linux_wait_for_event_1): Rename to ...
    	(linux_wait_for_event): ... here and merge it with former
    	linux_wait_for_event - new variable wait_ptid, use it.
    	(linux_wait_for_event): Remove - merge it to linux_wait_for_event_1.

-----------------------------------------------------------------------

Summary of changes:
 bfd/version.h                                |    2 +-
 gdb/ChangeLog                                |   41 +++++
 gdb/NEWS                                     |    8 +-
 gdb/ada-lang.c                               |   17 ++-
 gdb/amd64-linux-tdep.c                       |    2 +-
 gdb/arm-linux-tdep.c                         |    2 +-
 gdb/c-lang.c                                 |    8 +-
 gdb/corelow.c                                |   21 ++-
 gdb/d-lang.c                                 |    2 +-
 gdb/doc/gdb.texinfo                          |    4 +-
 gdb/dwarf2read.c                             |    4 +-
 gdb/elfread.c                                |   37 +++--
 gdb/f-lang.c                                 |    2 +-
 gdb/gdbarch.c                                |   96 ++++++------
 gdb/gdbarch.h                                |   28 ++--
 gdb/gdbarch.sh                               |   20 ++--
 gdb/gdbserver/ChangeLog                      |    7 +
 gdb/gdbserver/linux-low.c                    |   71 ++++------
 gdb/i386-linux-tdep.c                        |    2 +-
 gdb/jv-lang.c                                |    2 +-
 gdb/language.c                               |    6 +-
 gdb/language.h                               |   29 ++--
 gdb/linespec.c                               |   27 +++-
 gdb/m2-lang.c                                |    2 +-
 gdb/objc-lang.c                              |    2 +-
 gdb/opencl-lang.c                            |    2 +-
 gdb/p-lang.c                                 |    2 +-
 gdb/ppc-linux-tdep.c                         |    2 +-
 gdb/psymtab.c                                |    8 +-
 gdb/psymtab.h                                |    3 +-
 gdb/s390-tdep.c                              |    2 +-
 gdb/stap-probe.c                             |   88 ++++++------
 gdb/symfile.h                                |   10 +-
 gdb/symtab.c                                 |    6 +-
 gdb/testsuite/ChangeLog                      |   10 ++
 gdb/testsuite/gdb.base/watchpoint.exp        |  206 +++++++++-----------------
 gdb/testsuite/gdb.multi/watchpoint-multi.exp |   24 ++-
 gdb/version.in                               |    2 +-
 libiberty/ChangeLog                          |    5 +
 libiberty/make-relative-prefix.c             |    7 +-
 40 files changed, 421 insertions(+), 398 deletions(-)

First 500 lines of diff:
diff --git a/bfd/version.h b/bfd/version.h
index e195836..8a5e984 100644
--- a/bfd/version.h
+++ b/bfd/version.h
@@ -1,4 +1,4 @@
-#define BFD_VERSION_DATE 20120125
+#define BFD_VERSION_DATE 20120126
 #define BFD_VERSION @bfd_version@
 #define BFD_VERSION_STRING  @bfd_version_package@ @bfd_version_string@
 #define REPORT_BUGS_TO @report_bugs_to@
diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index 15a7b6a..b918a44 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,3 +1,44 @@
+2012-01-26  Pedro Alves  <palves@redhat.com>
+
+	* corelow.c (core_has_fake_pid): Delete.
+	(core_close): Delete references to `core_has_fake_pid'.
+	(add_to_thread_list): Adjust to mark the inferior's pid as fake.
+	(core_open): Delete references to `core_has_fake_pid'.
+	(core_pid_to_str): Adjust to check inferior->fake_pid_p instead of
+	the removed global.
+
+2012-01-26  Joel Brobecker  <brobecker@adacore.com>
+
+	* symfile.h (struct quick_symbol_functions) [expand_symtabs_matching]:
+	Remove language parameter from name_matcher.  Adjust the comment.
+	* symtab.c (search_symbols_name_matches, expand_partial_symbol_name):
+	Remove language parameter.
+	* ada-lang.c (ada_expand_partial_symbol_name): Likewise.
+	* linespec.c (iterate_name_matcher): Likewise.
+	* dwarf2read.c (dw2_expand_symtabs_matching): Adjust type of
+	name_matcher.  Adjust call accordingly.
+	* psymtab.c (expand_symtabs_matching_via_partial): Likewise.
+	(maintenance_check_symtabs): Adjust type of parameter "fun".
+	* psymtab.h (maintenance_check_symtabs): Likewise.
+
+2012-01-26  Joel Brobecker  <brobecker@adacore.com>
+
+	* language.h (symbol_name_match_p_ftype): New typedef.
+	(struct language_defn): Replace field la_symbol_name_compare
+	by la_get_symbol_name_match_p.
+	* ada-lang.c (ada_get_symbol_name_match_p): New function.
+	(ada_language_defn): Use it.
+	* linespec.c (struct symbol_matcher_data): New type.
+	(iterate_name_matcher): Rewrite.
+	(iterate_over_all_matching_symtabs): Pass a pointer to
+	a symbol_matcher_data struct to expand_symtabs_matching
+	instead of just the lookup name.
+	* c-lang.c, d-lang.c, jv-lang.c, m2-lang.c, objc-lang.c,
+	opencl-lang.c, p-lang.c, language.c: Delete field
+	la_symbol_name_compare, and replace by NULL for new field
+	la_get_symbol_name_match_p.
+	* symfile.h (struct quick_symbol_functions): Update comment.
+
 2012-01-25  Tom Tromey  <tromey@redhat.com>
 
 	* breakpoint.c (bpstat_stop_status): Check 'breakpoint_at' before
diff --git a/gdb/NEWS b/gdb/NEWS
index 8836f41..6a1a9c8 100644
--- a/gdb/NEWS
+++ b/gdb/NEWS
@@ -3,6 +3,10 @@
 
 *** Changes since GDB 7.4
 
+* GDB now has support for SystemTap <sys/sdt.h> probes.  You can set a
+  breakpoint using the new "-p" or "-probe" options and inspect the probe
+  arguments using the new $_probe_arg family of convenience variables.
+
 * Python scripting
 
   ** The "maint set python print-stack on|off" is now deleted.
@@ -336,10 +340,6 @@ Renesas RL78				rl78-*-elf
   Initial support for the OpenCL C language (http://www.khronos.org/opencl)
   has been integrated into GDB.
 
-* GDB now has support for SystemTap <sys/sdt.h> probes.  You can set a
-  breakpoint using the new "probe:" linespec and inspect the probe
-  arguments using the new $_probe_arg family of convenience variables.
-
 * Python scripting
 
   ** The function gdb.Write now accepts an optional keyword 'stream'.
diff --git a/gdb/ada-lang.c b/gdb/ada-lang.c
index 11ff73f..55e318f 100644
--- a/gdb/ada-lang.c
+++ b/gdb/ada-lang.c
@@ -5699,8 +5699,7 @@ struct add_partial_datum
 
 /* A callback for expand_partial_symbol_names.  */
 static int
-ada_expand_partial_symbol_name (const struct language_defn *language,
-				const char *name, void *user_data)
+ada_expand_partial_symbol_name (const char *name, void *user_data)
 {
   struct add_partial_datum *data = user_data;
   
@@ -12319,6 +12318,18 @@ static const struct exp_descriptor ada_exp_descriptor = {
   ada_evaluate_subexp
 };
 
+/* Implement the "la_get_symbol_name_match_p" language_defn method
+   for Ada.  */
+
+static symbol_name_match_p_ftype
+ada_get_symbol_name_match_p (const char *lookup_name)
+{
+  if (should_use_wild_match (lookup_name))
+    return wild_match;
+  else
+    return compare_names;
+}
+
 const struct language_defn ada_language_defn = {
   "ada",                        /* Language name */
   language_ada,
@@ -12355,7 +12366,7 @@ const struct language_defn ada_language_defn = {
   ada_print_array_index,
   default_pass_by_reference,
   c_get_string,
-  compare_names,
+  ada_get_symbol_name_match_p,	/* la_get_symbol_name_match_p */
   ada_iterate_over_symbols,
   LANG_MAGIC
 };
diff --git a/gdb/amd64-linux-tdep.c b/gdb/amd64-linux-tdep.c
index c30185d..e7e6f82 100644
--- a/gdb/amd64-linux-tdep.c
+++ b/gdb/amd64-linux-tdep.c
@@ -1366,7 +1366,7 @@ amd64_linux_init_abi (struct gdbarch_info info, struct gdbarch *gdbarch)
   set_gdbarch_stap_integer_prefix (gdbarch, "$");
   set_gdbarch_stap_register_prefix (gdbarch, "%");
   set_gdbarch_stap_register_indirection_prefix (gdbarch, "(");
-  set_gdbarch_stap_register_indirection_sufix (gdbarch, ")");
+  set_gdbarch_stap_register_indirection_suffix (gdbarch, ")");
   set_gdbarch_stap_is_single_operand (gdbarch, i386_stap_is_single_operand);
   set_gdbarch_stap_parse_special_token (gdbarch,
 					i386_stap_parse_special_token);
diff --git a/gdb/arm-linux-tdep.c b/gdb/arm-linux-tdep.c
index d710682..f58bfe0 100644
--- a/gdb/arm-linux-tdep.c
+++ b/gdb/arm-linux-tdep.c
@@ -1278,7 +1278,7 @@ arm_linux_init_abi (struct gdbarch_info info,
   set_gdbarch_stap_integer_prefix (gdbarch, "#");
   set_gdbarch_stap_register_prefix (gdbarch, "r");
   set_gdbarch_stap_register_indirection_prefix (gdbarch, "[");
-  set_gdbarch_stap_register_indirection_sufix (gdbarch, "]");
+  set_gdbarch_stap_register_indirection_suffix (gdbarch, "]");
   set_gdbarch_stap_gdb_register_prefix (gdbarch, "r");
   set_gdbarch_stap_is_single_operand (gdbarch, arm_stap_is_single_operand);
   set_gdbarch_stap_parse_special_token (gdbarch,
diff --git a/gdb/c-lang.c b/gdb/c-lang.c
index c4d841f..6e92fb9 100644
--- a/gdb/c-lang.c
+++ b/gdb/c-lang.c
@@ -863,7 +863,7 @@ const struct language_defn c_language_defn =
   default_print_array_index,
   default_pass_by_reference,
   c_get_string,
-  strcmp_iw_ordered,
+  NULL,				/* la_get_symbol_name_match_p */
   iterate_over_symbols,
   LANG_MAGIC
 };
@@ -986,7 +986,7 @@ const struct language_defn cplus_language_defn =
   default_print_array_index,
   cp_pass_by_reference,
   c_get_string,
-  strcmp_iw_ordered,
+  NULL,				/* la_get_symbol_name_match_p */
   iterate_over_symbols,
   LANG_MAGIC
 };
@@ -1027,7 +1027,7 @@ const struct language_defn asm_language_defn =
   default_print_array_index,
   default_pass_by_reference,
   c_get_string,
-  strcmp_iw_ordered,
+  NULL,				/* la_get_symbol_name_match_p */
   iterate_over_symbols,
   LANG_MAGIC
 };
@@ -1073,7 +1073,7 @@ const struct language_defn minimal_language_defn =
   default_print_array_index,
   default_pass_by_reference,
   c_get_string,
-  strcmp_iw_ordered,
+  NULL,				/* la_get_symbol_name_match_p */
   iterate_over_symbols,
   LANG_MAGIC
 };
diff --git a/gdb/corelow.c b/gdb/corelow.c
index 3e0c7cd..aa344c6 100644
--- a/gdb/corelow.c
+++ b/gdb/corelow.c
@@ -75,9 +75,6 @@ struct gdbarch *core_gdbarch = NULL;
    unix child targets.  */
 static struct target_section_table *core_data;
 
-/* True if we needed to fake the pid of the loaded core inferior.  */
-static int core_has_fake_pid = 0;
-
 static void core_files_info (struct target_ops *);
 
 static struct core_fns *sniff_core_bfd (bfd *);
@@ -217,7 +214,6 @@ core_close (int quitting)
 	  xfree (core_data);
 	  core_data = NULL;
 	}
-      core_has_fake_pid = 0;
 
       name = bfd_get_filename (core_bfd);
       gdb_bfd_close_or_warn (core_bfd);
@@ -244,6 +240,8 @@ add_to_thread_list (bfd *abfd, asection *asect, void *reg_sect_arg)
   int core_tid;
   int pid, lwpid;
   asection *reg_sect = (asection *) reg_sect_arg;
+  int fake_pid_p = 0;
+  struct inferior *inf;
 
   if (strncmp (bfd_section_name (abfd, asect), ".reg/", 5) != 0)
     return;
@@ -253,14 +251,18 @@ add_to_thread_list (bfd *abfd, asection *asect, void *reg_sect_arg)
   pid = bfd_core_file_pid (core_bfd);
   if (pid == 0)
     {
-      core_has_fake_pid = 1;
+      fake_pid_p = 1;
       pid = CORELOW_PID;
     }
 
   lwpid = core_tid;
 
-  if (current_inferior ()->pid == 0)
-    inferior_appeared (current_inferior (), pid);
+  inf = current_inferior ();
+  if (inf->pid == 0)
+    {
+      inferior_appeared (inf, pid);
+      inf->fake_pid_p = fake_pid_p;
+    }
 
   ptid = ptid_build (pid, lwpid, 0);
 
@@ -382,7 +384,6 @@ core_open (char *filename, int from_tty)
   init_thread_list ();
 
   inferior_ptid = null_ptid;
-  core_has_fake_pid = 0;
 
   /* Need to flush the register cache (and the frame cache) from a
      previous debug session.  If inferior_ptid ends up the same as the
@@ -849,6 +850,7 @@ static char *
 core_pid_to_str (struct target_ops *ops, ptid_t ptid)
 {
   static char buf[64];
+  struct inferior *inf;
   int pid;
 
   /* The preferred way is to have a gdbarch/OS specific
@@ -867,7 +869,8 @@ core_pid_to_str (struct target_ops *ops, ptid_t ptid)
 
   /* Otherwise, this isn't a "threaded" core -- use the PID field, but
      only if it isn't a fake PID.  */
-  if (!core_has_fake_pid)
+  inf = find_inferior_pid (ptid_get_pid (ptid));
+  if (inf != NULL && !inf->fake_pid_p)
     return normal_pid_to_str (ptid);
 
   /* No luck.  We simply don't have a valid PID to print.  */
diff --git a/gdb/d-lang.c b/gdb/d-lang.c
index da2785c..29dcfe4 100644
--- a/gdb/d-lang.c
+++ b/gdb/d-lang.c
@@ -272,7 +272,7 @@ static const struct language_defn d_language_defn =
   default_print_array_index,
   default_pass_by_reference,
   c_get_string,
-  strcmp_iw_ordered,
+  NULL,				/* la_get_symbol_name_match_p */
   NULL,
   LANG_MAGIC
 };
diff --git a/gdb/doc/gdb.texinfo b/gdb/doc/gdb.texinfo
index 5f65959..4696b69 100644
--- a/gdb/doc/gdb.texinfo
+++ b/gdb/doc/gdb.texinfo
@@ -4567,7 +4567,7 @@ given, all object files are considered.
 @end table
 
 @vindex $_probe_arg@r{, convenience variable}
-A probe may specify up to ten arguments.  These are available at the
+A probe may specify up to twelve arguments.  These are available at the
 point at which the probe is defined---that is, when the current PC is
 at the probe's location.  The arguments are available using the
 convenience variables (@pxref{Convenience Vars})
@@ -6597,7 +6597,7 @@ functions with identical names in different source files.
 @end table
 
 @cindex SystemTap static probe point
-@item -p @r{[}@var{objfile}:@r{]}@r{[}@var{provider}:@r{]}@var{name}
+@item [-p|-probe] @r{[}@var{objfile}:@r{]}@r{[}@var{provider}:@r{]}@var{name}
 The @sc{gnu}/Linux tool @code{SystemTap} provides a way for
 applications to embed static probes.  This form of linespec specifies
 the location of such a static probe.  See
diff --git a/gdb/dwarf2read.c b/gdb/dwarf2read.c
index 0ef0a5b..76f8510 100644
--- a/gdb/dwarf2read.c
+++ b/gdb/dwarf2read.c
@@ -2691,7 +2691,7 @@ static void
 dw2_expand_symtabs_matching
   (struct objfile *objfile,
    int (*file_matcher) (const char *, void *),
-   int (*name_matcher) (const struct language_defn *, const char *, void *),
+   int (*name_matcher) (const char *, void *),
    enum search_domain kind,
    void *data)
 {
@@ -2745,7 +2745,7 @@ dw2_expand_symtabs_matching
 
       name = index->constant_pool + MAYBE_SWAP (index->symbol_table[idx]);
 
-      if (! (*name_matcher) (current_language, name, data))
+      if (! (*name_matcher) (name, data))
 	continue;
 
       /* The name was matched, now expand corresponding CUs that were
diff --git a/gdb/elfread.c b/gdb/elfread.c
index aea443f..33e91d9 100644
--- a/gdb/elfread.c
+++ b/gdb/elfread.c
@@ -1612,32 +1612,33 @@ handle_probe (struct objfile *objfile, struct sdt_note *el,
   bfd *abfd = objfile->obfd;
   int size = bfd_get_arch_size (abfd) / 8;
   struct gdbarch *gdbarch = get_objfile_arch (objfile);
+  enum bfd_endian byte_order = gdbarch_byte_order (gdbarch);
   struct type *ptr_type = builtin_type (gdbarch)->builtin_data_ptr;
   CORE_ADDR base_ref;
 
   ret->gdbarch = gdbarch;
 
   /* Provider and the name of the probe.  */
-  ret->provider = (const char *) &el->data[3 * size];
+  ret->provider = &el->data[3 * size];
   ret->name = memchr (ret->provider, '\0',
-		      (unsigned long *) el->data
-		      + el->size - (unsigned long *) ret->provider);
+		      (char *) el->data + el->size - ret->provider);
   /* Making sure there is a name.  */
   if (!ret->name)
-    complaint (&symfile_complaints, _("corrupt probe when reading `%s'"),
-	       objfile->name);
+    {
+      complaint (&symfile_complaints, _("corrupt probe when reading `%s'"),
+		 objfile->name);
+      ret->provider = NULL;
+      ret->name = NULL;
+    }
   else
     ++ret->name;
 
   /* Retrieving the probe's address.  */
-  ret->address = extract_typed_address ((const gdb_byte *) &el->data[0],
-					ptr_type);
+  ret->address = extract_typed_address (&el->data[0], ptr_type);
   /* Link-time sh_addr of `.stapsdt.base' section.  */
-  base_ref = extract_typed_address ((const gdb_byte *) &el->data[size],
-				    ptr_type);
+  base_ref = extract_typed_address (&el->data[size], ptr_type);
   /* Semaphore address.  */
-  ret->sem_addr = extract_typed_address ((const gdb_byte *) &el->data[2 * size],
-					 ptr_type);
+  ret->sem_addr = extract_typed_address (&el->data[2 * size], ptr_type);
 
   ret->address += (ANOFFSET (objfile->section_offsets,
 			     SECT_OFF_TEXT (objfile))
@@ -1652,17 +1653,19 @@ handle_probe (struct objfile *objfile, struct sdt_note *el,
   if (ret->name)
     {
       ret->args = memchr (ret->name, '\0',
-			  (unsigned long *) el->data
-			  + el->size - (unsigned long *) ret->name);
+			  (char *) el->data + el->size - ret->name);
 
       if (ret->args != NULL)
 	++ret->args;
       if (ret->args == NULL
-	  || (memchr (ret->args, '\0', (unsigned long *) el->data
-		      + el->size - (unsigned long *) ret->name)
+	  || (memchr (ret->args, '\0',
+		      (char *) el->data + el->size - ret->name)
 	      != el->data + el->size - 1))
-	complaint (&symfile_complaints, _("corrupt probe when reading `%s'"),
-		   objfile->name);
+	{
+	  complaint (&symfile_complaints, _("corrupt probe when reading `%s'"),
+		     objfile->name);
+	  ret->args = NULL;
+	}
     }
   else
     ret->args = NULL;
diff --git a/gdb/f-lang.c b/gdb/f-lang.c
index 4149cef..5f15402 100644
--- a/gdb/f-lang.c
+++ b/gdb/f-lang.c
@@ -309,7 +309,7 @@ const struct language_defn f_language_defn =
   default_print_array_index,
   default_pass_by_reference,
   default_get_string,
-  strcmp_iw_ordered,
+  NULL,				/* la_get_symbol_name_match_p */
   iterate_over_symbols,
   LANG_MAGIC
 };
diff --git a/gdb/gdbarch.c b/gdb/gdbarch.c
index 431ddcc..d6f6040 100644
--- a/gdb/gdbarch.c
+++ b/gdb/gdbarch.c
@@ -266,13 +266,13 @@ struct gdbarch
   gdbarch_record_special_symbol_ftype *record_special_symbol;
   gdbarch_get_syscall_number_ftype *get_syscall_number;
   const char * stap_integer_prefix;
-  const char * stap_integer_sufix;
+  const char * stap_integer_suffix;
   const char * stap_register_prefix;
-  const char * stap_register_sufix;
+  const char * stap_register_suffix;
   const char * stap_register_indirection_prefix;
-  const char * stap_register_indirection_sufix;
+  const char * stap_register_indirection_suffix;
   const char * stap_gdb_register_prefix;
-  const char * stap_gdb_register_sufix;
+  const char * stap_gdb_register_suffix;
   gdbarch_stap_is_single_operand_ftype *stap_is_single_operand;
   gdbarch_stap_parse_special_token_ftype *stap_parse_special_token;
   int has_global_solist;
@@ -434,13 +434,13 @@ struct gdbarch startup_gdbarch =
   0,  /* record_special_symbol */
   0,  /* get_syscall_number */
   0,  /* stap_integer_prefix */
-  0,  /* stap_integer_sufix */
+  0,  /* stap_integer_suffix */
   0,  /* stap_register_prefix */
-  0,  /* stap_register_sufix */
+  0,  /* stap_register_suffix */
   0,  /* stap_register_indirection_prefix */
-  0,  /* stap_register_indirection_sufix */
+  0,  /* stap_register_indirection_suffix */
   0,  /* stap_gdb_register_prefix */
-  0,  /* stap_gdb_register_sufix */
+  0,  /* stap_gdb_register_suffix */
   0,  /* stap_is_single_operand */
   0,  /* stap_parse_special_token */
   0,  /* has_global_solist */
@@ -736,13 +736,13 @@ verify_gdbarch (struct gdbarch *gdbarch)
   /* Skip verify of record_special_symbol, has predicate.  */
   /* Skip verify of get_syscall_number, has predicate.  */
   /* Skip verify of stap_integer_prefix, invalid_p == 0 */
   /* Skip verify of stap_integer_sufix, invalid_p == 0 */
   /* Skip verify of stap_register_prefix, invalid_p == 0 */
   /* Skip verify of stap_register_sufix, invalid_p == 0 */
   /* Skip verify of stap_register_indirection_prefix, invalid_p == 0 */
   /* Skip verify of stap_register_indirection_sufix, invalid_p == 0 */
   /* Skip verify of stap_gdb_register_prefix, invalid_p == 0 */
   /* Skip verify of stap_gdb_register_sufix, invalid_p == 0 */
   /* Skip verify of stap_is_single_operand, has predicate.  */
   /* Skip verify of stap_parse_special_token, has predicate.  */
   /* Skip verify of has_global_solist, invalid_p == 0 */
@@ -1300,14 +1300,14 @@ gdbarch_dump (struct gdbarch *gdbarch, struct ui_file *file)
                       "gdbarch_dump: stap_gdb_register_prefix = %s\n",
                       gdbarch->stap_gdb_register_prefix);
   fprintf_unfiltered (file,
-                      "gdbarch_dump: stap_gdb_register_sufix = %s\n",
-                      gdbarch->stap_gdb_register_sufix);
+                      "gdbarch_dump: stap_gdb_register_suffix = %s\n",
+                      gdbarch->stap_gdb_register_suffix);
   fprintf_unfiltered (file,
                       "gdbarch_dump: stap_integer_prefix = %s\n",
                       gdbarch->stap_integer_prefix);
   fprintf_unfiltered (file,
-                      "gdbarch_dump: stap_integer_sufix = %s\n",
-                      gdbarch->stap_integer_sufix);
+                      "gdbarch_dump: stap_integer_suffix = %s\n",
+                      gdbarch->stap_integer_suffix);
   fprintf_unfiltered (file,
                       "gdbarch_dump: gdbarch_stap_is_single_operand_p() = %d\n",
                       gdbarch_stap_is_single_operand_p (gdbarch));
@@ -1324,14 +1324,14 @@ gdbarch_dump (struct gdbarch *gdbarch, struct ui_file *file)
                       "gdbarch_dump: stap_register_indirection_prefix = %s\n",
                       gdbarch->stap_register_indirection_prefix);
   fprintf_unfiltered (file,
-                      "gdbarch_dump: stap_register_indirection_sufix = %s\n",
-                      gdbarch->stap_register_indirection_sufix);
@@ -736,13 +736,13 @@ verify_gdbarch (struct gdbarch *gdbarch)
   /* Skip verify of get_syscall_number, has predicate.  */
   /* Skip verify of stap_integer_prefix, invalid_p == 0 */
-  /* Skip verify of stap_integer_sufix, invalid_p == 0 */
+  /* Skip verify of stap_integer_suffix, invalid_p == 0 */
   /* Skip verify of stap_register_prefix, invalid_p == 0 */
@@ -736,13 +736,13 @@ verify_gdbarch (struct gdbarch *gdbarch)
   /* Skip verify of stap_register_prefix, invalid_p == 0 */
-  /* Skip verify of stap_register_sufix, invalid_p == 0 */
+  /* Skip verify of stap_register_suffix, invalid_p == 0 */
   /* Skip verify of stap_register_indirection_prefix, invalid_p == 0 */
@@ -736,13 +736,13 @@ verify_gdbarch (struct gdbarch *gdbarch)
   /* Skip verify of stap_register_indirection_prefix, invalid_p == 0 */
-  /* Skip verify of stap_register_indirection_sufix, invalid_p == 0 */
+  /* Skip verify of stap_register_indirection_suffix, invalid_p == 0 */
   /* Skip verify of stap_gdb_register_prefix, invalid_p == 0 */
@@ -736,13 +736,13 @@ verify_gdbarch (struct gdbarch *gdbarch)
   /* Skip verify of stap_gdb_register_prefix, invalid_p == 0 */
-  /* Skip verify of stap_gdb_register_sufix, invalid_p == 0 */
+  /* Skip verify of stap_gdb_register_suffix, invalid_p == 0 */
   /* Skip verify of stap_is_single_operand, has predicate.  */
   /* Skip verify of stap_parse_special_token, has predicate.  */


hooks/post-receive
--
Repository for Project Archer.


             reply	other threads:[~2012-01-26 21:12 UTC|newest]

Thread overview: 6+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2012-01-26 21:12 sergiodj [this message]
  -- strict thread matches above, loose matches on Subject: below --
2012-02-27 17:54 sergiodj
2012-01-25 18:44 sergiodj
2012-01-18  3:20 sergiodj
2011-03-28 16:22 jkratoch
2011-03-20 13:35 jkratoch

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20120126211212.15564.qmail@sourceware.org \
    --to=sergiodj@sourceware.org \
    --cc=archer-commits@sourceware.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).